@@ -130,7 +130,7 @@ class walk(Task):
 
     def _iter_recursive(self, root):
         for path in root.iterdir():
-            if path.is_file():
+            if path.is_file() or path.is_symlink():
                 if path.name not in self.IGNORE:
                     yield path
             elif path.is_dir():
