@@ -9,9 +9,9 @@ class rename_replace(Task):
         self.replacement = replacement
 
     def process(self, inputs):
-        for t, c in inputs:
+        for t, c, m in inputs:
             t2 = Path(str(t).replace(self.substring, self.replacement))
-            yield t2, c
+            yield t2, c, m
 
 
 class strip_dirs(Task):
@@ -35,6 +35,6 @@ class strip_dirs(Task):
        writing the stream output to disk.
     """
     def process(self, inputs):
-        for t, c in inputs:
+        for t, c, m in inputs:
             t2 = Path(t.name)
-            yield t2, c
+            yield t2, c, m
