@@ -1,5 +1,3 @@
-from htmlmin import Minifier
-
 from ..core import Task
 
 
@@ -7,11 +5,16 @@ class minify_html(Task):
     """Minifies HTML input files."""
 
     def __init__(self, *htmlmin_args, **htmlmin_kwargs):
+        try:
+            from htmlmin import Minifier
+        except ImportError as e:
+            raise ImportError('To use minify_html(), run: pip install htmlmin') from e
+
         self.minifier = Minifier(*htmlmin_args, **htmlmin_kwargs)
 
     def lazy_minify(self, contents):
         yield self.minifier.minify(b''.join(contents).decode('utf-8')).encode('utf-8')
 
     def process(self, inputs):
-        for t, c in inputs:
-            yield t, self.lazy_minify(c)
+        for t, c, m in inputs:
+            yield t, self.lazy_minify(c), m
