@@ -1,3 +1,5 @@
+from functools import partial
+
 from ..core import Task
 
 
@@ -10,7 +12,9 @@ class markdown(Task):
         except ImportError as e:
             raise ImportError('To use markdown(), run: pip install markdown') from e
 
-        self.convert = markdown_fn
+        from markdown.extensions.codehilite import CodeHiliteExtension
+        hilite = CodeHiliteExtension(css_class='foo')
+        self.convert = partial(markdown_fn, extensions=['markdown.extensions.fenced_code', hilite])
 
     def lazy_convert(self, contents):
         yield self.convert(b''.join(contents).decode('utf-8')).encode('utf-8')
