@@ -26,7 +26,7 @@ class concat(Task):
         self.dest = Path(dest)
 
     def process(self, inputs):
-        yield self.dest, flatten(chain(c for _, c in inputs)), {}
+        yield self.dest, flatten(chain(c for _, c, _ in inputs)), {}
 
 
 class contents_replace(Task):
